==> certmanager-model-v1alpha3-5.7.3-sources.jar: annotations/io/fabric8/certmanager/api/model/v1alpha3/IssuerStatusFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder;
import java.util.function.Predicate;
import io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusFluentImpl;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
public class IssuerStatusFluentImpl<A extends io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent<A>{
  public IssuerStatusFluentImpl() {
  }
  public IssuerStatusFluentImpl(io.fabric8.certmanager.api.model.v1alpha3.IssuerStatus instance) {
    this.withAcme(instance.getAcme()); 
    this.withConditions(instance.getConditions()); 
  }
  private io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder acme;
  private java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> conditions;
  
  /**
   * This method has been deprecated, please use method buildAcme instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus getAcme() {
    return this.acme!=null?this.acme.build():null;
  }
  public io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus buildAcme() {
    return this.acme!=null?this.acme.build():null;
  }
  public A withAcme(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus acme) {
    _visitables.get("acme").remove(this.acme);
    if (acme!=null){ this.acme= new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder(acme); _visitables.get("acme").add(this.acme);} return (A) this;
  }
  public java.lang.Boolean hasAcme() {
    return this.acme != null;
  }
  public A withNewAcme(java.lang.String lastRegisteredEmail,java.lang.String uri) {
    return (A)withAcme(new ACMEIssuerStatus(lastRegisteredEmail, uri));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> withNewAcme() {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.AcmeNestedImpl();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> withNewAcmeLike(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus item) {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.AcmeNestedImpl(item);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> editAcme() {
    return withNewAcmeLike(getAcme());
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> editOrNewAcme() {
    return withNewAcmeLike(getAcme() != null ? getAcme(): new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder().build());
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> editOrNewAcmeLike(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus item) {
    return withNewAcmeLike(getAcme() != null ? getAcme(): item);
  }
  public A addToConditions(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition... items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(java.util.Collection<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition... items) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(java.util.Collection<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> items) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> getConditions() {
    return build(conditions);
  }
  public java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> buildConditions() {
    return build(conditions);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildCondition(java.lang.Integer index) {
    return this.conditions.get(index).build();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>(); for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public java.lang.Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type) {
    return (A)addToConditions(new IssuerCondition(lastTransitionTime, message, reason, status, type));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> addNewCondition() {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.ConditionsNestedImpl();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IssuerStatusFluentImpl that = (IssuerStatusFluentImpl) o;
    if (acme != null ? !acme.equals(that.acme) :that.acme != null) return false;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acme,  conditions,  super.hashCode());
  }
  public class AcmeNestedImpl<N> extends io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusFluentImpl<io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<N>> implements io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AcmeNestedImpl(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus item) {
      this.builder = new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder(this, item);
    }
    AcmeNestedImpl() {
      this.builder = new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder(this);
    }
    io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder builder;
    public N and() {
      return (N) IssuerStatusFluentImpl.this.withAcme(builder.build());
    }
    public N endAcme() {
      return and();
    }
    
  }
  public class ConditionsNestedImpl<N> extends io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionFluentImpl<io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<N>> implements io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConditionsNestedImpl(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
      this.index = index;
      this.builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(this);
    }
    io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) IssuerStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-5.12.2-sources.jar: annotations/io/fabric8/certmanager/api/model/v1alpha3/IssuerStatusFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder;
import java.util.function.Predicate;
import io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusFluentImpl;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
public class IssuerStatusFluentImpl<A extends io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent<A>{
  public IssuerStatusFluentImpl() {
  }
  public IssuerStatusFluentImpl(io.fabric8.certmanager.api.model.v1alpha3.IssuerStatus instance) {
    this.withAcme(instance.getAcme()); 
    this.withConditions(instance.getConditions()); 
  }
  private io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder acme;
  private java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> conditions;
  
  /**
   * This method has been deprecated, please use method buildAcme instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus getAcme() {
    return this.acme!=null?this.acme.build():null;
  }
  public io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus buildAcme() {
    return this.acme!=null?this.acme.build():null;
  }
  public A withAcme(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus acme) {
    _visitables.get("acme").remove(this.acme);
    if (acme!=null){ this.acme= new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder(acme); _visitables.get("acme").add(this.acme);} return (A) this;
  }
  public java.lang.Boolean hasAcme() {
    return this.acme != null;
  }
  public A withNewAcme(java.lang.String lastRegisteredEmail,java.lang.String uri) {
    return (A)withAcme(new ACMEIssuerStatus(lastRegisteredEmail, uri));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> withNewAcme() {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.AcmeNestedImpl();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> withNewAcmeLike(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus item) {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.AcmeNestedImpl(item);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> editAcme() {
    return withNewAcmeLike(getAcme());
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> editOrNewAcme() {
    return withNewAcmeLike(getAcme() != null ? getAcme(): new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder().build());
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<A> editOrNewAcmeLike(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus item) {
    return withNewAcmeLike(getAcme() != null ? getAcme(): item);
  }
  public A addToConditions(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition... items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(java.util.Collection<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder>();}
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition... items) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(java.util.Collection<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> items) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : items) {io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> getConditions() {
    return build(conditions);
  }
  public java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> buildConditions() {
    return build(conditions);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildCondition(java.lang.Integer index) {
    return this.conditions.get(index).build();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    for (io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(java.util.List<io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new java.util.ArrayList(); for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public java.lang.Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type) {
    return (A)addToConditions(new IssuerCondition(lastTransitionTime, message, reason, status, type));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> addNewCondition() {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.ConditionsNestedImpl();
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
    return new io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IssuerStatusFluentImpl that = (IssuerStatusFluentImpl) o;
    if (acme != null ? !acme.equals(that.acme) :that.acme != null) return false;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acme,  conditions,  super.hashCode());
  }
  public class AcmeNestedImpl<N> extends io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusFluentImpl<io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<N>> implements io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.AcmeNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AcmeNestedImpl(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatus item) {
      this.builder = new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder(this, item);
    }
    AcmeNestedImpl() {
      this.builder = new io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder(this);
    }
    io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEIssuerStatusBuilder builder;
    public N and() {
      return (N) IssuerStatusFluentImpl.this.withAcme(builder.build());
    }
    public N endAcme() {
      return and();
    }
    
  }
  public class ConditionsNestedImpl<N> extends io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionFluentImpl<io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<N>> implements io.fabric8.certmanager.api.model.v1alpha3.IssuerStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConditionsNestedImpl(java.lang.Integer index,io.fabric8.certmanager.api.model.v1alpha3.IssuerCondition item) {
      this.index = index;
      this.builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder(this);
    }
    io.fabric8.certmanager.api.model.v1alpha3.IssuerConditionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) IssuerStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}
